pub enum LayoutScope {
All,
Nodes {
nodes: BTreeSet<NodeId>,
},
}Expand description
Which nodes a layout request should include.
Variants
Implementations
Sourceimpl LayoutScope
impl LayoutScope
Sourcepub fn from_footprint(graph: &Graph, footprint: &GraphMutationFootprint) -> Self
pub fn from_footprint(graph: &Graph, footprint: &GraphMutationFootprint) -> Self
Derives a conservative node scope from a graph mutation footprint and the current graph.
Direct node changes are included. Port and edge changes expand to their owning endpoint nodes when that information is available in the current graph snapshot. Node ids that no longer exist in the supplied graph are omitted.
Sourcepub fn from_transaction(graph: &Graph, tx: &GraphTransaction) -> Self
pub fn from_transaction(graph: &Graph, tx: &GraphTransaction) -> Self
Derives a conservative node scope from a transaction and the current graph.